==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/formats/subrip/subripoutputformat.h <==
#ifndef SUBRIPOUTPUTFORMAT_H
#define SUBRIPOUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <outputformat.h>
#include <qstring.h>

namespace SubtitleComposer
{
	class SubRipOutputFormat : public OutputFormat
	{
		friend class FormatsManager;

		public:

			~SubRipOutputFormat() {}

			virtual QString dumpSubtitles( const Subtitle& subtitle, bool primary ) const
			{
				QString ret;

				for ( SubtitleIterator it( subtitle ); it.current(); ++it )
				{
					const SubtitleLine* line = it.current();

					Time showTime = line->showTime();
					Time hideTime = line->hideTime();
					ret += m_builder.sprintf(
						"%d\n%02d:%02d:%02d,%03d --> %02d:%02d:%02d,%03d\n",
						it.index() + 1,
						showTime.hours(), showTime.minutes(), showTime.seconds(), showTime.mseconds(),
						hideTime.hours(), hideTime.minutes(), hideTime.seconds(), hideTime.mseconds()
					);

					int styleFlags = line->styleFlags();

					ret += m_dialogueBuilder
						.arg( styleFlags & SubtitleLine::Bold ? m_boldStart : QString::null )
						.arg( styleFlags & SubtitleLine::Italic ? m_italicStart : QString::null )
						.arg( styleFlags & SubtitleLine::Underline ? m_underoffset : QString::null )
						.arg( (primary ? line->primaryText() : line->secondaryText()) )
						.arg( styleFlags & SubtitleLine::Underline ? m_underlineEnd : QString::null )
						.arg( styleFlags & SubtitleLine::Italic ? m_italicEnd : QString::null )
						.arg( styleFlags & SubtitleLine::Bold ? m_boldEnd : QString::null );
				}

				return ret;
			}

		protected:

			SubRipOutputFormat():
				OutputFormat( "SubRip", "srt" ),
				m_dialogueBuilder( "%1%2%3%4%5%6%7\n\n" ),
				m_boldStart( "<b>" ),
				m_boldEnd( "</b>" ),
				m_italicStart( "<i>" ),
				m_italicEnd( "</i>" ),
				m_underoffset( "<u>" ),
				m_underlineEnd( "</u>" )
			{
			}

			const QString m_dialogueBuilder;
			const QString m_boldStart;
			const QString m_boldEnd;
			const QString m_italicStart;
			const QString m_italicEnd;
			const QString m_underoffset;
			const QString m_underlineEnd;
			mutable QString m_builder;
	};
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/formats/subrip/subripoutputformat.h <==
#ifndef SUBRIPOUTPUTFORMAT_H
#define SUBRIPOUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <outputformat.h>

namespace SubtitleComposer
{
	class SubRipOutputFormat : public OutputFormat
	{
		friend class FormatManager;

		public:

			~SubRipOutputFormat() {}

			virtual QString dumpSubtitles( const Subtitle& subtitle, bool primary ) const
			{
				QString ret;

				for ( SubtitleIterator it( subtitle ); it.current(); ++it )
				{
					const SubtitleLine* line = it.current();

					Time showTime = line->showTime();
					Time hideTime = line->hideTime();
					ret += m_timeBuilder.sprintf(
						"%d\n%02d:%02d:%02d,%03d --> %02d:%02d:%02d,%03d\n",
						it.index() + 1,
						showTime.hours(), showTime.minutes(), showTime.seconds(), showTime.mseconds(),
						hideTime.hours(), hideTime.minutes(), hideTime.seconds(), hideTime.mseconds()
					);

					const SString& text = primary ? line->primaryText() : line->secondaryText();
					ret += text.richString();

					ret += "\n\n";
				}

				return ret;
			}

		protected:

			SubRipOutputFormat():
				OutputFormat( "SubRip", "srt" ),
				m_dialogueBuilder( "%1%2%3%4%5%6%7\n\n" )
			{
			}

			const QString m_dialogueBuilder;
			mutable QString m_timeBuilder;
	};
}

#endif
